@@ -23,7 +23,8 @@ log_likelihood_copula_model = function(theta,
                                        cdf_X,
                                        cdf_Y,
                                        pdf_X,
-                                       pdf_Y) {
+                                       pdf_Y,
+                                       return_sum = TRUE) {
   # The loglikelihood contribution in a copula model can be separated
   # into a part that depends only on the copula parameters, and a part
   # that only depends on the marginal distribution parameters. We can compute
@@ -33,7 +34,7 @@ log_likelihood_copula_model = function(theta,
   u = cdf_X(X)
   v = cdf_Y(Y)
   # loglikelihood contribution for the copula part.
-  loglik_copula = loglik_copula_scale(theta, u, v, d1, d2, copula_family)
+  loglik_copula = loglik_copula_scale(theta, u, v, d1, d2, copula_family, return_sum = return_sum)
 
 
   # Log likelihood contribution for the marginal distribution part.
@@ -55,7 +56,14 @@ log_likelihood_copula_model = function(theta,
   # When both observations are censored the likelihood does not depend
   # (directly) on the marginal part. The dependence on the marginal part is only
   # through the copula itself.
-  loglik = sum(part1 + part2 + part3) + loglik_copula
+  if (return_sum) {
+    loglik = sum(part1 + part2 + part3) + loglik_copula
+  }
+  else {
+    loglik = part1 + part2 + part3 + loglik_copula
+  }
+
+  return(loglik)
 }
 
 #' Function factory for distribution functions
